AtomFeed class

Represents an Atom feed See https://tools.ietf.org/html/rfc4287

Constructors

AtomFeed({String? id, String? title, DateTime? updated, List<AtomItem>? items, List<AtomLink>? links, List<AtomPerson>? authors, List<AtomPerson>? contributors, List<AtomCategory>? categories, AtomGenerator? generator, String? icon, String? rights, String? subtitle})
Default constructor for the AtomFeed class
AtomFeed.parse(String xmlString)
Parse constructor for the AtomFeed class, used when 'parsing' a feed
factory

Properties

authors → List<AtomPerson>?
The feed authors
final
categories → List<AtomCategory>?
The feed categories
final
contributors → List<AtomPerson>?
The feed contributors
final
generator → AtomGenerator?
The feed generator
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
The feed icon
final
id → String?
The feed id
final
items → List<AtomItem>?
The feed items
final
The feed links
final
The feed logo
final
rights → String?
The feed rights
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
The feed subtitle
final
title → String?
The feed title
final
updated → DateTime?
The feed updated date
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited