AtomGenerator class

Used to identify the agent used to generate a feed See https://tools.ietf.org/html/rfc4287#section-4.2.4

Constructors

AtomGenerator(String? uri, String? version, String? value)
Default constructor for the AtomGenerator class
AtomGenerator.parse(XmlElement element)
Parse constructor for the AtomGenerator class, used when 'parsing' a feed
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
The URI of the software used to generate the feed, must be an IRI reference
final
value → String?
The name of the generating agent
final
version → String?
The version of the generating agent
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited