ItunesEpisodeType enum

Different types of Episodes in the Itunes RSS specification. See https://help.apple.com/itc/podcasts_connect/#/itcb54353390

Inheritance
Available extensions

Values

full → const ItunesEpisodeType

The default type, used when submitting the complete content of a show.

trailer → const ItunesEpisodeType

Used when submitting a short, promotional piece of content

bonus → const ItunesEpisodeType

Used when submitting extra content for a show.

unknown → const ItunesEpisodeType

A fallback type.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ItunesEpisodeType>
A constant List of the values in this enum, in order of their declaration.