Description class

Constructors

Description({String? type, String? value})
Default constructor for the Description class
Description.parse(XmlElement element)
Parse constructor for the Description class, used when 'parsing' a feed
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
The type of the description
final
value → String?
The value of the description
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited