Text class

The text of a media element See https://www.rssboard.org/media-rss#media-text

Constructors

Text({String? type, String? lang, String? start, String? end, String? value})
Default constructor for the Text class
Text.parse(XmlElement element)
Parse constructor for the Text class, used when 'parsing' a feed
factory

Properties

end → String?
The end of the text
final
hashCode → int
The hash code for this object.
no setterinherited
lang → String?
The language of the text
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → String?
The start of the text
final
type → String?
The type of the text
final
value → String?
The value of the text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited