RssCloud class

Allows processes to register with a cloud to be notified of changes See https://www.rssboard.org/rss-specification#ltcloudgtSubelementOfLtchannelgt

Constructors

RssCloud(String? domain, String? port, String? path, String? registerProcedure, String? protocol)
Default constructor for the RssCloud class
RssCloud.parse(XmlElement node)
Parse constructor for the RssCloud class, used when 'parsing' a feed
factory

Properties

domain → String?
The domain of the cloud
final
hashCode → int
The hash code for this object.
no setterinherited
path → String?
The path of the cloud endpoint
final
port → String?
The port of the cloud endpoint
final
protocol → String?
The protocol of the cloud endpoint
final
registerProcedure → String?
The register procedure of the cloud
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited