RssSource class

Constructors

RssSource(String? url, String? value)
Default constructor for the RssSource class
RssSource.parse(XmlElement element)
Parse constructor for the RssSource class, used when 'parsing' a feed
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
The url of the source
final
value → String?
The value of the source
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited